Enum wellen::SignalEncoding
source · pub enum SignalEncoding {
String,
Real,
BitVector(NonZeroU32),
}Expand description
Specifies how the underlying signal of a variable is encoded.
This is different from the VarType which tries to correspond to the variable type in the
source HDL code.
Variants
String
encoded as variable length strings
Real
encoded as 64-bit floating point values
BitVector(NonZeroU32)
encoded as a fixed width bit-vector
Implementations
sourceimpl SignalEncoding
impl SignalEncoding
pub fn bit_vec_of_len(len: u32) -> Self