#[repr(u8)]pub enum States {
Two = 0,
Four = 1,
Nine = 2,
}Variants
Implementations
Sourceimpl States
impl States
pub fn from_bit(value: Bit) -> Self
pub fn from_ascii_bit(bit: u8) -> Option<(Self, Bit)>
pub fn from_ascii(string: &[u8]) -> Option<Self>
pub fn from_bits(bits: impl Iterator<Item = Bit>) -> Self
pub fn join(a: Self, b: Self) -> Self
pub fn mask(self) -> u8
Sourcepub fn bits_in_a_byte(self) -> u32
pub fn bits_in_a_byte(self) -> u32
Returns how many signal bits can be encoded in a u8.
Sourcepub fn bytes_required(self, bits: u32) -> usize
pub fn bytes_required(self, bits: u32) -> usize
Returns how many bytes are required to store bits.